@@ -416,7 +416,11 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 
 	new_max = coef10 * (1UL << (base10 * 10));
 	procman_debug("bak %u new_max %u pow2 %u coef10 %u", bak_max, new_max, pow2, coef10);
-	g_assert(bak_max <= new_max);
+
+	if (bak_max > new_max) {
+		procman_debug("overflow detected: bak=%u > new=%u", bak_max, new_max);
+		new_max = bak_max;
+	}
 
 	if (new_max == g->net.max)
 		return;
@@ -467,6 +471,18 @@ get_net (LoadGraph *g)
 		if (netload.if_flags & (1 << GLIBTOP_IF_FLAGS_LOOPBACK))
 			continue;
 
+		/* Skip interfaces without any IPv4/IPv6 address (or
+		 those with only a LINK ipv6 addr) However we need to
+		 be able to exclude these while still keeping the
+		 value so when they get online (with NetworkManager
+		 for example) we don't get a suddent peak.  Once we're
+		 able to get this, ignoring down interfaces will be
+		 possible too.  */
+		if (not (netload.flags & (1 << GLIBTOP_NETLOAD_ADDRESS6)
+			 and netload.scope6 != GLIBTOP_IF_IN6_SCOPE_LINK)
+		    and not (netload.flags & (1 << GLIBTOP_NETLOAD_ADDRESS)))
+			continue;
+
 		/* Don't skip interfaces that are down (GLIBTOP_IF_FLAGS_UP)
 		   to avoid spikes when they are brought up */
 
